@@ -12,14 +12,11 @@
 #include "genericListWidget.h"
 
 #include <QHeaderView>
-#include <QTreeWidgetItemIterator>
 #include <QVBoxLayout>
-#include <QPixmap>
 #include <QKeyEvent>
 #include <QAction>
 
-#include <klocale.h>
-#include <kglobalsettings.h>
+#include <KLocalizedString>
 
 #include "ctcron.h"
 #include "cttask.h"
@@ -27,7 +24,6 @@
 #include "crontabWidget.h"
 #include "taskWidget.h"
 #include "taskEditorDialog.h"
-#include "kcronIcons.h"
 
 #include "logging.h"
 
@@ -46,7 +42,7 @@ public:
 /**
  * Construct tasks folder from branch.
  */
-GenericListWidget::GenericListWidget(CrontabWidget* crontabWidget, const QString& label, const QPixmap& icon) :
+GenericListWidget::GenericListWidget(CrontabWidget* crontabWidget, const QString& label, const QIcon& icon) :
 	QWidget(crontabWidget), d(new GenericListWidgetPrivate()) {
 
 	QVBoxLayout* mainLayout = new QVBoxLayout(this);
@@ -58,7 +54,7 @@ GenericListWidget::GenericListWidget(CrontabWidget* crontabWidget, const QString
 	QHBoxLayout* labelLayout = new QHBoxLayout();
 
 	QLabel* tasksIcon = new QLabel(this);
-	tasksIcon->setPixmap(icon);
+	tasksIcon->setPixmap(icon.pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize, 0, this)));
 	labelLayout->addWidget(tasksIcon);
 
 	QLabel* tasksLabel = new QLabel(label, this);
@@ -77,7 +73,7 @@ GenericListWidget::GenericListWidget(CrontabWidget* crontabWidget, const QString
 
 	d->treeWidget->header()->setSortIndicatorShown(true);
 	d->treeWidget->header()->setStretchLastSection(true);
-	d->treeWidget->header()->setMovable(true);
+	d->treeWidget->header()->setSectionsMovable(true);
 
 	d->treeWidget->setSortingEnabled(true);
 	d->treeWidget->setAnimated(true);
